@@ -1,6 +1,11 @@
-package App::Nopaste::Service::ssh;
 use strict;
 use warnings;
+package App::Nopaste::Service::ssh;
+$App::Nopaste::Service::ssh::VERSION = '0.93';
+BEGIN {
+  $App::Nopaste::Service::ssh::AUTHORITY = 'cpan:SARTAK';
+}
+
 use base 'App::Nopaste::Service';
 use File::Temp;
 use File::Spec;
@@ -21,7 +26,7 @@ sub run {
                     : 1;
 
     my $date = strftime("%Y-%m-%d",localtime());
-    my ($ext) = defined $source && $source =~ s/(\.[^.]+?)$// ? $1 : '';
+    my ($ext) = defined $source && $source =~ s/(\.[^.\/\\]+?)$// ? $1 : '';
 
     my $suffix = $ext;
     if ($usedesc) {
